@@ -278,6 +278,10 @@ class JABElement(object):
         """
         self.bridge.releaseJavaObject(self.vmid, jabelement.accessible_context)
 
+    def request_focus(self):
+        """Request focus for a JABElement."""
+        self.bridge.requestFocus(self.vmid, self.accessible_context)
+
     def click(self) -> None:
         """Clicks the JABElement."""
         self.win32_utils._set_window_foreground(hwnd=self.hwnd.value)
@@ -298,9 +302,24 @@ class JABElement(object):
             raise TypeError(
                 "JABElement role '{}' does not support clear".format(self.role_en_us)
             )
-        self.click()
+        self.win32_utils._set_window_foreground(hwnd=self.hwnd.value)
+        self.request_focus()
         self.shortcut_keys.clear_text()
 
+    def select(self, value: str) -> None:
+        """Select a dropdown item from selector."""
+        if not self.accessible_selection:
+            raise AttributeError("Current JABElement does not support selection")
+        labels = self.find_elements_by_role("label")
+        for index, label in enumerate(labels):
+            if value == label.name:
+                self.bridge.addAccessibleSelectionFromContext(
+                    self.vmid, self.accessible_context, index
+                )
+                break
+        else:
+            raise ValueError(f"Option '{value}' does not found")
+
     def is_checked(self) -> bool:
         """Returns whether the JABElement is checked.
 
@@ -764,6 +783,7 @@ class JABElement(object):
                 continue
             if self._is_match_attributes(node_attributes, _jabelement):
                 jabelements.append(_jabelement)
+                continue
             self.release_jabelement(_jabelement)
         return jabelements
 
